package junit.log4j;
/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html
 */

import org.apache.log4j.PatternLayout;
import org.apache.log4j.helpers.PatternParser;

// Configuration Management Information: 
// -------------------------------------
// $Id: JUnitLayout.java,v 1.1 2001/11/17 22:38:46 wreissen Exp $
//
// Version History:
// ----------------
// $Log: JUnitLayout.java,v $
// Revision 1.1  2001/11/17 22:38:46  wreissen
// initial version.
//
//
// ***********************************************************************************
/**
 * <p>Extension of {@link org.apache.log4j.PatternLayout} to provide
 * stack traces of throwables in the appenders. The additionally recognized
 * conversion characters are:
 * <table border="1" CELLPADDING="8">
 *   <tr>
 *     <th>Conversion Character</th>
 *     <th>Effect</th>
 *     </tr>
 *     <tr>
 *       <td><b>T</b></td>
 *       <td>Print the stack trace of the throwable.</td>
 *     </tr>
 * </table>
 * </p>
 *
 *
 * Created: Sat Nov 17 15:09:19 2001
 *
 * @author <a href="mailto:wolfgang@openfuture.de">Wolfgang Reissenberger</a>
 * @version $Revision: 1.1 $
 */

public class JUnitLayout extends PatternLayout {
    
    /**
     * Creates a new <code>JUnitLayout</code> instance.
     *
     */
    public JUnitLayout() {
	super(DEFAULT_CONVERSION_PATTERN);
    }


    /**
     * Creates a new <code>JUnitLayout</code> instance.
     *
     * @param pattern the conversion pattern
     */
    public JUnitLayout(String pattern) {
	super(pattern);
    }


    /**
     * Creates a new {@link junit.log4j.JUnitPatternParser}.
     *
     * @param pattern conversion pattern
     * @return a new {@link junit.log4j.JUnitPatternParser}
     */
    public PatternParser createPatternParser(String pattern) {

	PatternParser result;

	if (pattern == null)
          result = new JUnitPatternParser(DEFAULT_CONVERSION_PATTERN);
       else
          result = new JUnitPatternParser(pattern);

       return result;

   }    
} // JUnitLayout
