package junit.log4j;
/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.<p>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.<p>
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA<br>
 * http://www.gnu.org/copyleft/lesser.html
 */

import junit.framework.AssertionFailedError;
import junit.framework.Test;
import junit.framework.TestResult;

import org.apache.log4j.Category;
import org.apache.log4j.Priority;
import org.apache.log4j.spi.LoggingEvent;

/**
 * Test result that joins <a href="http://www.junit.org">JUnit</a> and
 * <a href="http://jakarta.apache.org/log4j">Log4J</a>.
 * <p>
 *
 *
 * Created: Sat Nov 03 19:03:14 2001
 *
 * @author <a href="mailto:wolfgang@openfuture.de">Wolfgang Reissenberger</a>
 * @version $Revision: 1.4 $
 */

public class LoggedTestResult extends TestResult {
    
    /**
     * Creates a new <code>LoggedTestResult</code> instance.
     *
     */
    public LoggedTestResult() {
	super();
    }



    /**
     * Calls {@link junit.framework.TestResult#addError(junit.framework.Test, Throwable)
     *              TestResult.addError(test, throwable)}
     * and additionally adds the error as
     * {@link junit.log4j.JUnitAppenderSingleton#addLoggingEvent(org.apache.log4j.spi.LoggingEvent) logging event}
     * to the {@link junit.log4j.JUnitAppenderSingleton appender singleton}.
     *
     * @param test the test receiving the error
     * @param throwable a value of type 'Throwable'
     */
    public synchronized void addError(Test test, Throwable throwable) {
	super.addError(test, throwable);

	LoggingEvent event =
	    new LoggingEvent(test.getClass().getName(),
			     Category.getInstance(test.getClass()),
			     Priority.ERROR, "Error detected: ",
			     throwable);

	JUnitAppenderSingleton.addLoggingEvent(event);
    }



    /**
     * Calls
     * {@link junit.framework.TestResult#addFailure(junit.framework.Test,
     *                                              junit.framework.AssertionFailedError)
     *              TestResult.addFailure(test, throwable)}
     * and additionally adds the error as
     * {@link junit.log4j.JUnitAppenderSingleton#addLoggingEvent(org.apache.log4j.spi.LoggingEvent) logging event}
     * to the {@link junit.log4j.JUnitAppenderSingleton appender singleton}.
     *
     * @param test the test receiving the failure
     * @param failure assertion failure
     */
    public synchronized void addFailure(Test test,
					AssertionFailedError failure) {

	super.addFailure(test, failure);

	if (test == null || failure == null) return;

	LoggingEvent event =
	    new LoggingEvent(test.getClass().getName(),
			     Category.getInstance(test.getClass()),
			     Priority.ERROR,
			     "Assertion failure: ",
			     failure);

	JUnitAppenderSingleton.addLoggingEvent(event);
    }

} // LoggedTestResult
//Configuration Management Information: 
//-------------------------------------
//$Id: LoggedTestResult.java,v 1.4 2003/08/30 20:13:48 wreissen Exp $
//
//Version History:
//----------------
//$Log: LoggedTestResult.java,v $
//Revision 1.4  2003/08/30 20:13:48  wreissen
//imports corrected
//
//Revision 1.3  2001/11/17 22:40:38  wreissen
//Due to the introduction of JUnitLayout, the throwable may be
//traced by the layout and there is no necessity any more to
//set it in the message of the LogEvent.
//
//Revision 1.2  2001/11/12 21:36:14  wreissen
//javadoc bug fixes
//
//Revision 1.1  2001/11/12 17:57:15  wreissen
//initial version.
//
//
//***********************************************************************************
